# libestudos
Módulo para exemplificar construção de projetos Python no curso PyTools

Contribuindo com projetos de codigo aberto.

Link do curso [PyTools](https://plataforma.dev.pro.br/31287-pytools)

[![Build Status](https://www.travis-ci.com/danielngd/libestudos.svg?branch=main)](https://www.travis-ci.com/danielngd/libestudos)
[![Updates](https://pyup.io/repos/github/danielngd/libestudos/shield.svg)](https://pyup.io/repos/github/danielngd/libestudos/)
[![Python 3](https://pyup.io/repos/github/danielngd/libestudos/python-3-shield.svg)](https://pyup.io/repos/github/danielngd/libestudos/)


Suportado versão 3 de Python

Para instalar:

```console
python3 -m venv .venv
source .venv/bin/activate
pip install -r requirements-dev.txt
```

Para conferir a qualidade do código:

```console
flake8

```

Topicos a serem abordados:
1. Git
2. Virtualenv
3. Pip